@@ -1,10 +1,11 @@
-library(markdown)
-library(ggplot2)
-library(tidyr)
-library(dplyr)
-library(SingleCaseES)
-library(rlang)
+library(markdown, warn.conflicts = FALSE, quietly = TRUE)
+library(ggplot2, warn.conflicts = FALSE, quietly = TRUE)
+library(tidyr, warn.conflicts = FALSE, quietly = TRUE)
+library(dplyr, warn.conflicts = FALSE, quietly = TRUE)
+library(SingleCaseES, warn.conflicts = FALSE, quietly = TRUE)
+library(rlang, warn.conflicts = FALSE, quietly = TRUE)
 
+source("mappings.R")
 
 statistical_indices <- c("NAP","Tau","SMD","LRRi", "LRRd", "LOR")
 
@@ -133,7 +134,8 @@ shinyServer(function(input, output, session) {
   })
   
   output$datview <- renderTable(datFile())
-    
+  output$datview2 <- renderTable(datFile())
+  
   output$clusterPhase <- renderUI({
       var_names <- names(datFile())
       if (input$dat_type == "dat") {
@@ -154,22 +156,25 @@ shinyServer(function(input, output, session) {
   
   output$phaseDefine <- renderUI({
     
-    phase_choices <- unique(datFile()[input$b_phase])
+    
+    phase_choices <- if (!is.null(input$b_phase)) unique(datFile()[[input$b_phase]]) else c("A","B")
+    trt_choices <- setdiff(phase_choices, input$b_base)
     
     if (input$dat_type == "dat") {
       list(
-        selectInput("b_base", label = "Baseline Phase Value", choices = phase_choices)
-        # selectInput("b_treat", label = "Treatment Phase Value", choices = phase_choices)
+        selectInput("b_base", label = "Baseline Phase Value", choices = phase_choices),
+        selectInput("b_treat", label = "Treatment Phase Value", choices = trt_choices)
       )
     } else {
       curMap <- exampleMapping[[input$example]]
       list(
-        selectInput("b_base", label = "Baseline Phase Value", choices = phase_choices, selected = curMap$phase_vals[1])
-        # selectInput("b_treat", label = "Treatment Phase Value", choices = phase_choices, selected = curMap$phase_vals[2])  
+        selectInput("b_base", label = "Baseline Phase Value", choices = phase_choices, selected = curMap$phase_vals[1]),
+        selectInput("b_treat", label = "Treatment Phase Value", choices = trt_choices, selected = curMap$phase_vals[2])  
       )
     }
   })
-  
+
+    
   output$outOrderImp <- renderUI({
 
     var_names <- names(datFile())
@@ -268,14 +273,16 @@ shinyServer(function(input, output, session) {
     }
     
     batch_calc_ES(dat = datFile(), 
+                  grouping = input$b_clusters,
                   condition = input$b_phase, 
                   outcome = input$b_out,
                   session_number = input$session_number,
-                  grouping = input$b_clusters,
                   baseline_phase = input$b_base,
+                  intervention_phase = input$b_treat,
                   ES = c(input$bESno, input$bESpar),
                   improvement = improvement,
                   scale = scale_val,
+                  std_dev = input$bSMD_denom,
                   format = input$resultsformat)
 
   })
